@@ -21,7 +21,6 @@ import logging
 import logging.config
 import os
 import os.path
-from pymongo import MongoClient
 import pwd
 import requests
 import re
@@ -72,7 +71,7 @@ class CLI(object):
 
         self.ferry_server = 'http://127.0.0.1:4000'
         self.default_user = 'root'
-        self.installer = Installer()
+        self.installer = Installer(self)
 
     def _pull_image(self, image):
         """
@@ -369,16 +368,20 @@ class CLI(object):
                 connectors.append(c)
 
             backends = json_data[uuid]['backends']
+            bstore = []
+            cstore = []
             for b in backends:
                 if b['storage']:
-                    storage.append(b['storage'])
+                    bstore.append(b['storage'])
                 else:
-                    storage.append(' ')
+                    bstore.append(' ')
 
                 if b['compute']:
-                    compute.append(b['compute'])
+                    cstore.append(b['compute'])
                 else:
-                    compute.append(' ')
+                    cstore.append(' ')
+            storage.append(bstore)
+            compute.append(cstore)
 
             status.append(json_data[uuid]['status'])
             base.append(json_data[uuid]['base'])
@@ -589,24 +592,40 @@ class CLI(object):
 
         return json_text
 
-    def _read_key_dir(self):
+    def _read_key_dir(self, root=False):
         """
         Read the location of the directory containing the keys
         used to communicate with the containers. 
         """
-        f = open(ferry.install.DEFAULT_DOCKER_KEY, 'r')
-        k = f.read().strip().split("://")
-        return k[1], k[0]
+        if root:
+            keydir = ferry.install.DEFAULT_ROOT_KEY
+        else:
+            keydir = ferry.install.DEFAULT_DOCKER_KEY
+        with open(keydir, 'r') as f: 
+            k = f.read().strip().split("://")
+            return k[1], k[0]
 
     def _using_tmp_ssh_key(self):
-        keydir, tmp = self._read_key_dir()
+        """
+        Check if the key being used is a temporary key. 
+        """
+        keydir, tmp = self._read_key_dir(root=True)
         return tmp == "tmp"
 
-    def _check_ssh_key(self):
-        keydir, _ = self._read_key_dir()
+    def _check_ssh_key(self, root=False):
+        """
+        Check if the user has supplied a custom key
+        directory. If not copies over a temporary key. 
+        """
+        keydir, _ = self._read_key_dir(root)
         if keydir == ferry.install.DEFAULT_KEY_DIR:
-            keydir = os.environ['HOME'] + '/.ssh/tmp-ferry'
-            ferry.install.GLOBAL_KEY_DIR = 'tmp://' + keydir
+            if root:
+                keydir = os.environ['HOME'] + '/.ssh/tmp-root'
+                ferry.install.GLOBAL_ROOT_DIR = 'tmp://' + keydir
+            else:
+                keydir = os.environ['HOME'] + '/.ssh/tmp-ferry'
+                ferry.install.GLOBAL_KEY_DIR = 'tmp://' + keydir
+
             try:
                 os.makedirs(keydir)
             except OSError as e:
@@ -631,8 +650,12 @@ class CLI(object):
                     logging.error("Could not override keys in %s, please delete those keys and try again." % keydir)
                 exit(1)
 
-            ferry.install._touch_file(ferry.install.DEFAULT_DOCKER_KEY, 
-                                      ferry.install.GLOBAL_KEY_DIR)
+            if root:
+                ferry.install._touch_file(ferry.install.DEFAULT_ROOT_KEY, 
+                                          ferry.install.GLOBAL_ROOT_DIR)
+            else:
+                ferry.install._touch_file(ferry.install.DEFAULT_DOCKER_KEY, 
+                                          ferry.install.GLOBAL_KEY_DIR)
             logging.warning("Copied ssh keys to " + ferry.install.GLOBAL_KEY_DIR)
 
 
@@ -729,13 +752,13 @@ class CLI(object):
 
             return self._connect_stack(stack_id, connector_id)
         elif(cmd == 'quit'):
-            self._check_ssh_key()
+            self._check_ssh_key(root=True)
             self._stop_all()
             self.installer.stop_web()
             self.installer._stop_docker_daemon()
 
             if self._using_tmp_ssh_key():
-                self.installer._reset_ssh_key()
+                self.installer._reset_ssh_key(root=True)
             return 'stopped ferry'
         elif(cmd == 'deploy'):
             self._check_ssh_key()
