@@ -20,10 +20,6 @@ from string import Template
 from ferry.config.openmpi.mpiconfig import *
 
 class OpenMPIClientInitializer(object):
-    """
-    Create a new initializer
-    Param user The user login for the git repo
-    """
     def __init__(self):
         self.mpi = OpenMPIInitializer()
         self.container_data_dir = self.mpi.container_data_dir
@@ -45,15 +41,9 @@ class OpenMPIClientInitializer(object):
     def template_repo(self, value):
         self.mpi.template_repo = value
 
-    """
-    Generate a new hostname
-    """
     def new_host_name(self, instance_id):
         return 'openmpi_client' + str(instance_id)
 
-    """
-    Start the service on the containers. 
-    """
     def start_service(self, containers, entry_point, fabric):
         self.mpi.start_service(containers, entry_point, fabric)
     def restart_service(self, containers, entry_point, fabric):
@@ -61,29 +51,15 @@ class OpenMPIClientInitializer(object):
     def stop_service(self, containers, entry_point, fabric):        
         self.mpi.stop_service(containers, entry_point, fabric)
 
-    """
-    Get the ports necessary.
-    """
     def get_necessary_ports(self, num_instances):
         return self.mpi.get_necessary_ports(num_instances)
 
-    """
-    Get the internal ports. 
-    """
     def get_exposed_ports(self, num_instances):
         return self.mpi.get_exposed_ports(num_instances)
 
-    """
-    Generate a new configuration
-    Param num Number of instances that need to be configured
-    Param image Image type of the instances
-    """
     def generate(self, num):
         return self.mpi.generate(num)
 
-    """
-    Apply the configuration to the instances
-    """
     def apply(self, config, containers):
         config_dirs, entry_point = self.mpi.apply(config, containers)
         entry_point['type'] = 'mpi-client'
