@@ -19,10 +19,6 @@ import sys
 from string import Template
 
 class OpenMPIInitializer(object):
-    """
-    Create a new initializer
-    Param user The user login for the git repo
-    """
     def __init__(self):
         self.template_dir = None
         self.template_repo = None
@@ -30,39 +26,41 @@ class OpenMPIInitializer(object):
         self.container_data_dir = None
         self.container_log_dir = MPIConfig.log_directory
 
-    """
-    Generate a new hostname
-    """
     def new_host_name(self, instance_id):
+        """
+        Generate a new hostname
+        """
         return 'openmpi' + str(instance_id)
 
-    """
-    Start the service on the containers. 
-    """
     def _execute_service(self, containers, entry_point, fabric, cmd):
-        output = fabric.cmd(containers, '/service/sbin/startnode %s %s' % (cmd, entry_point['mount']))
+        """
+        Start the service on the containers. 
+        """
+        fabric.cmd(containers[:1], '/service/sbin/startnode %s %s %s' % (cmd, entry_point['mount'], 'master'))
+        fabric.cmd(containers[1:len(containers)], '/service/sbin/startnode %s %s %s' % (cmd, entry_point['mount'], 'slave'))
     def start_service(self, containers, entry_point, fabric):
         self._execute_service(containers, entry_point, fabric, "start")
     def restart_service(self, containers, entry_point, fabric):
         self._execute_service(containers, entry_point, fabric, "restart")
     def stop_service(self, containers, entry_point, fabric):        
         self._execute_service(containers, entry_point, fabric, "stop")
-    """
-    Generate a new configuration.
-    """
+
     def _generate_config_dir(self, uuid):
+        """
+        Generate a new configuration.
+        """
         return 'openmpi_' + str(uuid)
 
-    """
-    Get the ports necessary.
-    """
     def get_necessary_ports(self, num_instances):
+        """
+        Get the ports necessary.
+        """
         return []
 
-    """
-    Get the internal ports. 
-    """
     def get_exposed_ports(self, num_instances):
+        """
+        Get the internal ports. 
+        """
         BTL_PORT_END = MPIConfig.BTL_PORT_MIN + (MPIConfig.PORT_RANGE * num_instances)
         OOB_PORT_END = MPIConfig.OOB_PORT_MIN + (MPIConfig.PORT_RANGE * num_instances)
         BTL_PORTS = '%s-%s' % (MPIConfig.BTL_PORT_MIN, BTL_PORT_END)
@@ -77,12 +75,13 @@ class OpenMPIInitializer(object):
 
         return instances
 
-    """
-    Generate a new configuration
-    Param num Number of instances that need to be configured
-    Param image Image type of the instances
-    """
     def generate(self, num):
+        """
+        Generate a new configuration
+        Param num Number of instances that need to be configured
+        Param image Image type of the instances
+
+        """
         config = MPIConfig(num)
         config.btl_port_min = MPIConfig.BTL_PORT_MIN
         config.oob_port_min = MPIConfig.OOB_PORT_MIN
@@ -91,10 +90,10 @@ class OpenMPIInitializer(object):
 
         return config
 
-    """
-    Generate the mca-params configuration. 
-    """
     def _generate_mca_params(self, config, new_config_dir):
+        """
+        Generate the mca-params configuration. 
+        """
         in_file = open(self.template_dir + '/openmpi-mca-params.conf', 'r')
         out_file = open(new_config_dir + '/openmpi-mca-params.conf', 'w+')
 
@@ -109,10 +108,28 @@ class OpenMPIInitializer(object):
         in_file.close()
         out_file.close()
 
-    """
-    Apply the configuration to the instances
-    """
+    def _find_mpi_storage(self, containers):
+        """
+        Find a MPI compatible storage entry. 
+        """
+        for c in containers:
+            for s in c['storage']:
+                if s['type'] == 'gluster':
+                    return s
+
+    def _find_mpi_compute(self, containers):
+        """
+        Find a MPI compatible compute entry. 
+        """
+        for c in containers:
+            for s in c['compute']:
+                if s['type'] == 'openmpi':
+                    return s
+    
     def apply(self, config, containers):
+        """
+        Apply the configuration to the instances
+        """
         entry_point = { 'type' : 'openmpi' }
         config_dirs = []
 
@@ -124,24 +141,26 @@ class OpenMPIInitializer(object):
 
         # For now the MPI client assumes there is only one storage and that it is
         # a Gluster end point. 
-        storage = containers[0]['storage'][0]
-        if storage['type'] == 'gluster':
-            mount_ip = storage['ip']
+        storage = self._find_mpi_storage(containers)
+        if storage:
+            mount_ip = storage['gluster']
             mount_dir = storage['volume']
             entry_point['mount'] = "%s:/%s" % (mount_ip, mount_dir)
 
             # Check if we are being called as a compute instance or client.
             if not 'compute' in containers[0]:
+                entry_point['hosts'] = []
                 entry_point['instances'] = []
                 for server in containers:
                     entry_point['instances'].append([server['data_ip'], server['host_name']])
+                    entry_point['hosts'].append([server['data_ip'], server['host_name']])
             else:
                 # This is the MPI client. Create a "hosts" file that contains the
                 # IP addresses of the compute nodes. 
                 entry_point['ip'] = containers[0]['data_ip']
-                compute = containers[0]['compute'][0]
+                compute = self._find_mpi_compute(containers)
                 with open(new_config_dir + '/hosts', 'w+') as hosts_file:
-                    for c in compute['instances']:
+                    for c in compute['hosts']:
                         hosts_file.write(c[0] + "\n")
 
             self._generate_mca_params(config, new_config_dir)
@@ -153,8 +172,8 @@ class OpenMPIInitializer(object):
         return config_dirs, entry_point
 
 class MPIConfig(object):
-    log_directory = '/service/logs'
-    config_directory = '/service/conf/openmpi'
+    log_directory = '/service/logs/'
+    config_directory = '/service/conf/openmpi/'
 
     BTL_PORT_MIN = 2000
     OOB_PORT_MIN = 6000
