@@ -147,8 +147,7 @@ class SparkInitializer(object):
             # This is being called as a client service. 
             # For the client, also include the host/IP of the compute service. 
             compute = containers[0]['compute'][0]
-            master = compute['master']
-            entry_point['master'] = master
+            entry_point['master'] = compute['master']
 
         # Transfer the configuration. 
         for c in containers:
@@ -160,8 +159,8 @@ class SparkInitializer(object):
         return config_dirs, entry_point
 
 class SparkConfig(object):
-    log_directory = '/service/packages/spark/logs'
-    config_directory = '/service/conf/spark'
+    log_directory = '/service/packages/spark/logs/'
+    config_directory = '/service/conf/spark/'
 
     MASTER_PORT = 7077
     SLAVE_PORT = 7078
