@@ -14,14 +14,21 @@ def mkdir(directory):
 def mount(entry_point, mount_point):
     # Check if the mount point exists. If not
     # go ahead and create it. 
-    # mount -t glusterfs entry_point mount_point
     cmd = 'mount -t glusterfs %s %s' % (entry_point,
                                         mount_point)
     output = Popen(cmd, stdout=PIPE, shell=True).stdout.read()
     logging.info(cmd)
     logging.info(output)
 
+def umount(mount_point):
+    cmd = 'umount %s' % mount_point
+    output = Popen(cmd, stdout=PIPE, shell=True).stdout.read()
+    logging.info(cmd)
+    logging.info(output)
+
 cmd = sys.argv[1]
 if cmd == "mount":
     entry = sys.argv[2]
     mount(entry, '/service/data')
+elif cmd == "umount":
+    umount('/service/data')
