@@ -30,11 +30,14 @@ import stat
 import struct
 import sys
 import time
+import uuid
 import yaml
 from distutils import spawn
+from ferry.ip.client import DHCPClient
+from ferry.config.mongo.mongoconfig import *
+from ferry.docker.fabric import DockerFabric
 from string import Template
 from subprocess import Popen, PIPE
-from ferry.ip.client import DHCPClient
 
 def _get_ferry_home():
     if 'FERRY_HOME' in os.environ:
@@ -103,6 +106,7 @@ FERRY_HOME=_get_ferry_home()
 DEFAULT_IMAGE_DIR=FERRY_HOME + '/data/dockerfiles'
 DEFAULT_KEY_DIR=FERRY_HOME + '/data/key'
 GLOBAL_KEY_DIR=DEFAULT_KEY_DIR
+GLOBAL_ROOT_DIR=FERRY_HOME + '/data/key'
 DEFAULT_DOCKER_LOGIN=os.environ['HOME'] + '/.ferry.docker'
 DEFAULT_DOCKER_REPO='ferry'
 GUEST_DOCKER_REPO='ferry-user'
@@ -111,6 +115,7 @@ DOCKER_CMD='docker-ferry'
 DOCKER_SOCK='unix:////var/run/ferry.sock'
 DOCKER_DIR='/var/lib/ferry'
 DOCKER_PID='/var/run/ferry.pid'
+DEFAULT_TEMPLATE_DIR=FERRY_HOME + '/data/templates'
 DEFAULT_BUILTIN_APPS=FERRY_HOME + '/data/plans'
 DEFAULT_FERRY_APPS='/var/lib/ferry/apps'
 DEFAULT_MONGO_DB='/var/lib/ferry/mongo'
@@ -118,10 +123,16 @@ DEFAULT_MONGO_LOG='/var/lib/ferry/mongolog'
 DEFAULT_REGISTRY_DB='/var/lib/ferry/registry'
 DEFAULT_DOCKER_LOG='/var/lib/ferry/docker.log'
 DEFAULT_DOCKER_KEY='/var/lib/ferry/keydir'
+DEFAULT_ROOT_KEY='/var/lib/ferry/rootdir'
 
 class Installer(object):
-    def __init__(self):
+    def __init__(self, cli=None):
         self.network = DHCPClient()
+        self.fabric = DockerFabric(bootstrap=True)
+        self.mongo = MongoInitializer()
+        self.mongo.fabric = self.fabric
+        self.mongo.template_dir = DEFAULT_TEMPLATE_DIR + '/mongo/'
+        self.cli = cli
 
     def get_ferry_account(self):
         """
@@ -158,19 +169,14 @@ class Installer(object):
             logging.error(e)
             return None
 
-    def _read_key_dir(self):
-        """
-        Find the directory containing the container keys. 
-        """
-        f = open(ferry.install.DEFAULT_DOCKER_KEY, 'r')
-        k = f.read().strip().split("://")
-        return k[1], k[0]
-
     def _clean_rules(self):
         self.network.clean_rules()
 
-    def _reset_ssh_key(self):
-        keydir, tmp = self._read_key_dir()
+    def _reset_ssh_key(self, root=False):
+        """
+        Reset the temporary ssh key. 
+        """
+        keydir, tmp = self.cli._read_key_dir(root)
 
         # Only reset temporary keys. User-defined key directories
         # shouldn't be touched. 
@@ -178,19 +184,32 @@ class Installer(object):
             shutil.rmtree(keydir)
 
         # Mark that we are using the default package keys
-        global GLOBAL_KEY_DIR
-        GLOBAL_KEY_DIR = 'tmp://' + DEFAULT_KEY_DIR
-        _touch_file(DEFAULT_DOCKER_KEY, GLOBAL_KEY_DIR, root=True)
-        logging.warning("reset key directory " + GLOBAL_KEY_DIR)
-        
-    def _process_ssh_key(self, options):
-        global GLOBAL_KEY_DIR
-        if options and '-k' in options:
-            GLOBAL_KEY_DIR = 'user://' + self.fetch_image_keys(options['-k'][0])
+        if root:
+            global GLOBAL_ROOT_DIR
+            GLOBAL_ROOT_DIR = 'tmp://' + DEFAULT_KEY_DIR
+            _touch_file(DEFAULT_ROOT_KEY, GLOBAL_ROOT_DIR, root=True)
         else:
+            global GLOBAL_KEY_DIR
             GLOBAL_KEY_DIR = 'tmp://' + DEFAULT_KEY_DIR
-        logging.warning("using key directory " + GLOBAL_KEY_DIR)
-        _touch_file(DEFAULT_DOCKER_KEY, GLOBAL_KEY_DIR, root=True)
+            _touch_file(DEFAULT_DOCKER_KEY, GLOBAL_KEY_DIR, root=True)
+        
+    def _process_ssh_key(self, options, root=False):
+        if root:
+            global GLOBAL_ROOT_DIR
+            if options and '-k' in options:
+                GLOBAL_ROOT_DIR = 'user://' + self.fetch_image_keys(options['-k'][0])
+            else:
+                GLOBAL_ROOT_DIR = 'tmp://' + DEFAULT_KEY_DIR
+                logging.warning("using key directory " + GLOBAL_ROOT_DIR)
+                _touch_file(DEFAULT_ROOT_KEY, GLOBAL_ROOT_DIR, root=True)
+        else:
+            global GLOBAL_KEY_DIR
+            if options and '-k' in options:
+                GLOBAL_KEY_DIR = 'user://' + self.fetch_image_keys(options['-k'][0])
+            else:
+                GLOBAL_KEY_DIR = 'tmp://' + DEFAULT_KEY_DIR
+                logging.warning("using key directory " + GLOBAL_KEY_DIR)
+                _touch_file(DEFAULT_DOCKER_KEY, GLOBAL_KEY_DIR, root=True)
 
     def install(self, args, options):
         # Check if the host is actually 64-bit. If not raise a warning and quit.
@@ -282,6 +301,16 @@ class Installer(object):
         else:
             return True
 
+    def _transfer_config(self, config_dirs):
+        """
+        Transfer the configuration to the containers. 
+        """
+        for c in config_dirs:
+            container = c[0]
+            from_dir = c[1]
+            to_dir = c[2]
+            self.fabric.copy([container], from_dir, to_dir)
+
     def start_web(self, options=None, clean=False):
         start, msg = self._start_docker_daemon(options)
         if not clean and not start:
@@ -291,7 +320,7 @@ class Installer(object):
             sys.exit(1)
 
         # Check if the user wants to use a specific key directory. 
-        self._process_ssh_key(options)
+        self._process_ssh_key(options, root=True)
 
         # Check if the user-application directory exists.
         # If not, create it. 
@@ -327,31 +356,48 @@ class Installer(object):
         # Check if there are any other Mongo instances runnig.
         self._clean_web()
 
-        # Start the Mongo server.
-        keydir, _ = self._read_key_dir()
-        cmd = DOCKER_CMD + ' -H=' + DOCKER_SOCK + ' run -d -v %s:%s -v %s:%s -v %s:%s %s/mongodb' % (keydir, '/service/keys',
-                                                                                                     DEFAULT_MONGO_DB, '/service/data',
-                                                                                                     DEFAULT_MONGO_LOG, '/service/logs',
-                                                                                                     DEFAULT_DOCKER_REPO)
-        logging.warning(cmd)
-        child = Popen(cmd, stdout=PIPE, stderr=PIPE, shell=True)
-        output = child.stderr.read().strip()
-        if re.compile('[/:\s\w]*Can\'t connect[\'\s\w]*').match(output):
-            logging.error("Ferry docker daemon does not appear to be running")
-            sys.exit(1)
-        elif re.compile('Unable to find image[\'\s\w]*').match(output):
-            logging.error("Ferry mongo image not present")
+        # Copy over the ssh keys.
+        self.cli._check_ssh_key(root=True)
+
+        # Start the Mongo server. Create a new configuration and
+        # manually start the container. 
+        keydir, _ = self.cli._read_key_dir(root=True)
+        volumes = { DEFAULT_MONGO_LOG : self.mongo.container_log_dir,
+                    DEFAULT_MONGO_DB : self.mongo.container_data_dir }
+        mongoplan = {'image':'ferry/mongodb',
+                     'type':'ferry/mongodb', 
+                     'volumes':volumes,
+                     'volume_user':DEFAULT_FERRY_OWNER, 
+                     'keys': { '/service/keys' : keydir }, 
+                     'ports':[],
+                     'exposed':self.mongo.get_exposed_ports(1), 
+                     'hostname':'ferrydb',
+                     'netenable':True, 
+                     'args': 'trust'
+                     }
+        mongoconf = self.mongo.generate(1)
+        mongoconf.uuid = 'fdb-' + str(uuid.uuid4()).split('-')[0]
+        mongobox = self.fabric.alloc([mongoplan])[0]
+        if not mongobox:
+            logging.error("Could not start MongoDB image")
             sys.exit(1)
 
-        # Need to get Mongo connection info and store in temp file. 
-        container = child.stdout.read().strip()
-        cmd = DOCKER_CMD + ' -H=' + DOCKER_SOCK + ' inspect %s' % container
-        logging.warning(cmd)
-        output = Popen(cmd, stdout=PIPE, shell=True).stdout.read()
-        output_json = json.loads(output.strip())
-        ip = output_json[0]['NetworkSettings']['IPAddress']
+        ip = mongobox.internal_ip
         _touch_file('/tmp/mongodb.ip', ip, root=True)
 
+        # Once the container is started, we'll need to copy over the
+        # configuration files, and then manually send the 'start' command. 
+        s = { 'container':mongobox,
+              'data_dev':'eth0', 
+              'data_ip':mongobox.internal_ip, 
+              'manage_ip':mongobox.internal_ip,
+              'host_name':mongobox.host_name,
+              'type':mongobox.service_type,
+              'args':mongobox.args }
+        config_dirs, entry_point = self.mongo.apply(mongoconf, [s])
+        self._transfer_config(config_dirs)
+        self.mongo.start_service([mongobox], entry_point, self.fabric)
+
         # Set the MongoDB env. variable. 
         my_env = os.environ.copy()
         my_env['MONGODB'] = ip
@@ -380,11 +426,16 @@ class Installer(object):
             ip = f.read().strip()
             f.close()
 
-            keydir, tmp = self._read_key_dir()
+            keydir, tmp = self.cli._read_key_dir(root=True)
             key = keydir + "/id_rsa"
-            cmd = 'ssh -o StrictHostKeyChecking=no -o UserKnownHostsFile=/dev/null -i %s root@%s /service/bin/mongodb stop' % (key, ip)
+            cmd = 'ssh -o StrictHostKeyChecking=no -o UserKnownHostsFile=/dev/null -i %s root@%s /service/sbin/startnode stop' % (key, ip)
             logging.warning(cmd)
             output = Popen(cmd, stdout=PIPE, shell=True).stdout.read()
+            logging.warning(output)
+            cmd = 'ssh -o StrictHostKeyChecking=no -o UserKnownHostsFile=/dev/null -i %s root@%s /service/sbin/startnode halt' % (key, ip)
+            logging.warning(cmd)
+            output = Popen(cmd, stdout=PIPE, shell=True).stdout.read()
+            logging.warning(output)
             os.remove('/tmp/mongodb.ip')
 
         # Kill all the gunicorn instances. 
